==> haskell-time-locale-compat-0.1.1.5-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-locale-compat
version:              0.1.1.5
visibility:           public
id:                   time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
key:                  time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
license:              BSD-3-Clause
copyright:            Copyright (c) 2014-2018 Kei Hibino
maintainer:           ex8k.hibino@gmail.com
author:               Kei Hibino
homepage:             https://github.com/khibino/haskell-time-locale-compat
synopsis:             Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.

category:             System
abi:                  614c8e43369c7a74d0b806ae06c712ac
exposed:              True
exposed-modules:      Data.Time.Locale.Compat
import-dirs:          /usr/lib/ghc-8.10.4/site-local/time-locale-compat-0.1.1.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/time-locale-compat-0.1.1.5

hs-libraries:         HStime-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
depends:              base-4.14.1.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock

haddock-html:         /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-locale-compat-0.1.1.5-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-locale-compat
version:              0.1.1.5
visibility:           public
id:                   time-locale-compat-0.1.1.5-5cx66yU3Sl5G8ah6lp8xSQ
key:                  time-locale-compat-0.1.1.5-5cx66yU3Sl5G8ah6lp8xSQ
license:              BSD-3-Clause
copyright:            Copyright (c) 2014-2018 Kei Hibino
maintainer:           ex8k.hibino@gmail.com
author:               Kei Hibino
homepage:             https://github.com/khibino/haskell-time-locale-compat
synopsis:             Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.

category:             System
abi:                  59912e931f6cba0dc450ce5b5c3ee8d5
exposed:              True
exposed-modules:      Data.Time.Locale.Compat
import-dirs:          /usr/lib/ghc-8.10.5/site-local/time-locale-compat-0.1.1.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/time-locale-compat-0.1.1.5

hs-libraries:         HStime-locale-compat-0.1.1.5-5cx66yU3Sl5G8ah6lp8xSQ
depends:              base-4.14.2.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock

haddock-html:         /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
